pub fn introspect_spec_with_data(
descriptor: &SpecDescriptor,
game_data: ResolvedGameData,
) -> Result<SpecIntrospection, ApplicationError>Expand description
Build a full introspection snapshot for a spec, including hero talents.
pub fn introspect_spec_with_data(
descriptor: &SpecDescriptor,
game_data: ResolvedGameData,
) -> Result<SpecIntrospection, ApplicationError>Build a full introspection snapshot for a spec, including hero talents.